@@ -600,7 +600,9 @@ class GbpOptionParser(OptionParser):
 
         try:
             self.parse_config_files()
-        except (configparser.ParsingError, configparser.DuplicateSectionError) as err:
+        except (configparser.ParsingError,
+                configparser.DuplicateOptionError,
+                configparser.DuplicateSectionError) as err:
             raise GbpError(str(err) + "\nSee 'man gbp.conf' for the format.")
 
         OptionParser.__init__(self, option_class=GbpOption,
