@@ -105,7 +105,7 @@ class Patch(object):
                 self.info[header] = value.strip()
         # Body
         try:
-            self.long_desc = "".join([l.decode("utf-8", "backslashreplace") for l in body])
+            self.long_desc = "".join([li.decode("utf-8", "backslashreplace") for li in body])
         except (IOError, UnicodeDecodeError) as msg:
             raise GbpError("Failed to read patch header of '%s': %s" %
                            (self.path, msg))
@@ -145,7 +145,7 @@ class Patch(object):
             if ext in self.patch_exts:
                 subject = base
         except ValueError:
-                pass  # No ext so keep subject as is
+            pass  # No ext so keep subject as is
         return subject.lstrip('0123456789-') or subject
 
     def _get_info_field(self, key, get_val=None):
@@ -334,6 +334,7 @@ class PatchSeries(list):
 
         >>> PatchSeries._read_series(['a/b',
         ...                           'a -p1 # comment',
+        ...                           '',
         ...                           'a/b -p2'], '.')
         ... # doctest:+NORMALIZE_WHITESPACE
         [<gbp.patch_series.Patch path='./a/b' topic='a' >,
@@ -349,8 +350,11 @@ class PatchSeries(list):
         @type patch_dir: string
         """
         queue = PatchSeries()
+        ws = re.compile('^\\s+$')
         for line in series:
             try:
+                if ws.match(line):
+                    continue
                 if line[0] in ['\n', '#']:
                     continue
             except IndexError:
