@@ -134,9 +134,18 @@ def test_pristine_has_commit():
     >>> repo.pristine_tar.has_commit('upstream', '1.0')
     True
     >>> branch = repo.rev_parse('pristine-tar')
-    >>> commit = repo.pristine_tar.get_commit('upstream_1.0.orig.tar.gz')
+    >>> commit, sig = repo.pristine_tar.get_commit('upstream_1.0.orig.tar.gz')
     >>> branch == commit
     True
+    >>> sig
+    True
+    >>> repo.pristine_tar.commit('../upstream_1.0.orig.tar.gz', 'upstream')
+    >>> branch = repo.rev_parse('pristine-tar')
+    >>> commit, sig = repo.pristine_tar.get_commit('upstream_1.0.orig.tar.gz')
+    >>> branch == commit
+    True
+    >>> sig
+    False
     """
 
 
@@ -200,7 +209,7 @@ def test_pristine_tar_checkout_nonexistent():
     >>> repo = gbp.deb.git.DebianGitRepository(dirs['repo'])
     >>> _gbp_log_err_bak = gbp.log.err
     >>> gbp.log.err = lambda x: None
-    >>> repo.pristine_tar.checkout('upstream', '1.1', 'gzip', '..')
+    >>> repo.pristine_tar.checkout('upstream', '1.1', 'gzip', '..') # doctest:+IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
     ...
     gbp.command_wrappers.CommandExecFailed: Pristine-tar couldn't checkout "upstream_1.1.orig.tar.gz": fatal: Path 'upstream_1.1.orig.tar.gz.delta' does not exist in 'refs/heads/pristine-tar'
